@@ -32,8 +32,8 @@ mainwindow::mainwindow(QWidget *parent) :
     connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged()));
     orientationChanged();
     readvalues();
-    abouttext = "<br />Author: d-iivil<br />Licence: GPL";
-    abouttitle = "CSSU Transitions Tuner ver. 0.0.9";
+    abouttext = tr("Author: d-iivil<br />Licence: GPL");
+    abouttitle = "CSSU Transitions Tuner " + tr("version") + " 0.1.0";
 }
 
 mainwindow::~mainwindow()
@@ -212,212 +212,198 @@ void mainwindow::storevalues()
     QSettings settings2(path2, QSettings::IniFormat);
     QSettings settings3(path3, QSettings::IniFormat);
 
+    double parallaxint = ui->parallax->value();
+    if (parallaxint == 0) parallaxint = 1;
+    QString parallax = QString::number(parallaxint);
+    parallax.replace(',', '.');
+
+    int radius_moreint = ui->blur->value();
+    QString radius_more = QString::number(radius_moreint);
+
     settings.beginGroup("thp_tweaks");
 
-    if (settings.contains("blurless")) {
+  //  if (settings.contains("blurless")) {
         if ( ui->blurless->checkState() == Qt::Checked ) {
             settings.setValue("blurless","1");
         } else {
             settings.setValue("blurless","0");
         }
-    }
+   // }
 
-    if (settings.contains("taskswitcher")) {
+  //  if (settings.contains("taskswitcher")) {
         settings.setValue("taskswitcher", ui->taskswitcher->currentIndex());
-    }
+  //  }
 
-    if (settings.contains("zaxisrotation")) {
+//    if (settings.contains("zaxisrotation")) {
         if ( ui->zaxis->checkState() == Qt::Checked ) {
             settings.setValue("zaxisrotation", "1");
         } else {
             settings.setValue("zaxisrotation", "0");
         }
-    }
+//    }
 
-    if (settings.contains("tactilepopups")) {
+//    if (settings.contains("tactilepopups")) {
         if ( ui->tactile->checkState() == Qt::Checked ) {
             settings.setValue("tactilepopups", "1");
         } else {
             settings.setValue("tactilepopups", "0");
         }
-    }
+//    }
 
-    if (settings.contains("forcerotation")) {
+//    if (settings.contains("forcerotation")) {
         if ( ui->forcerotation->checkState() == Qt::Checked ) {
             settings.setValue("forcerotation", "1");
         } else {
             settings.setValue("forcerotation", "0");
         }
-    }
+//    }
 
 
      settings.endGroup();
 
      settings.beginGroup("home");
 
-     if (settings.contains("zoom_on_press")) {
+  //   if (settings.contains("zoom_on_press")) {
         if ( ui->zoomonpress->checkState() == Qt::Checked ) {
             settings.setValue("zoom_on_press", "1");
         } else {
             settings.setValue("zoom_on_press", "0");
         }
-     }
+  //   }
 
-     if (settings.contains("parallax")) {
-         double parallaxint = ui->parallax->value();
-         QString parallax = QString::number(parallaxint);
-         parallax.replace(',', '.');
-        // QMaemo5InformationBox::information(this, parallax, QMaemo5InformationBox::DefaultTimeout);
+  //   if (settings.contains("parallax")) {
         settings.setValue("parallax", parallax);
-    }
+ //   }
 
-     if (settings.contains("radius_more")) {
-         int radius_moreint = ui->blur->value();
-         QString radius_more = QString::number(radius_moreint);
-      //   parallax.replace(',', '.');
-        // QMaemo5InformationBox::information(this, parallax, QMaemo5InformationBox::DefaultTimeout);
+ //    if (settings.contains("radius_more")) {
         settings.setValue("radius_more", radius_more);
-    }
+ //   }
 
      settings.endGroup();
 
      settings2.beginGroup("thp_tweaks");
 
-     if (settings2.contains("blurless")) {
+  //   if (settings2.contains("blurless")) {
          if ( ui->blurless->checkState() == Qt::Checked ) {
              settings2.setValue("blurless","1");
          } else {
              settings2.setValue("blurless","0");
          }
-     }
+  //   }
 
-     if (settings2.contains("taskswitcher")) {
+ //    if (settings2.contains("taskswitcher")) {
          settings2.setValue("taskswitcher", ui->taskswitcher->currentIndex());
-     }
+ //    }
 
-     if (settings2.contains("zaxisrotation")) {
+ //    if (settings2.contains("zaxisrotation")) {
          if ( ui->zaxis->checkState() == Qt::Checked ) {
              settings2.setValue("zaxisrotation", "1");
          } else {
              settings2.setValue("zaxisrotation", "0");
          }
-     }
+ //    }
 
-     if (settings2.contains("forcerotation")) {
+ //    if (settings2.contains("forcerotation")) {
          if ( ui->forcerotation->checkState() == Qt::Checked ) {
              settings2.setValue("forcerotation", "1");
          } else {
              settings2.setValue("forcerotation", "0");
          }
-     }
+  //   }
 
-     if (settings2.contains("tactilepopups")) {
+//     if (settings2.contains("tactilepopups")) {
          if ( ui->tactile->checkState() == Qt::Checked ) {
              settings2.setValue("tactilepopups", "1");
          } else {
              settings2.setValue("tactilepopups", "0");
          }
-     }
+//     }
 
 
       settings2.endGroup();
 
       settings2.beginGroup("home");
 
-      if (settings2.contains("zoom_on_press")) {
+  //    if (settings2.contains("zoom_on_press")) {
          if ( ui->zoomonpress->checkState() == Qt::Checked ) {
              settings2.setValue("zoom_on_press", "1");
          } else {
              settings2.setValue("zoom_on_press", "0");
          }
-      }
+ //     }
 
 
    //      double parallaxdouble = ui->parallax->value();
-      if (settings2.contains("parallax")) {
-          double parallaxint = ui->parallax->value();
-          QString parallax = QString::number(parallaxint);
-          parallax.replace(',', '.');
+   //   if (settings2.contains("parallax")) {
          settings2.setValue("parallax", parallax);
-     }
+  //   }
 
-      if (settings2.contains("radius_more")) {
-          int radius_moreint = ui->blur->value();
-          QString radius_more = QString::number(radius_moreint);
-       //   parallax.replace(',', '.');
-         // QMaemo5InformationBox::information(this, parallax, QMaemo5InformationBox::DefaultTimeout);
+ //     if (settings2.contains("radius_more")) {
          settings2.setValue("radius_more", radius_more);
-     }
+  //   }
 
       settings2.endGroup();
 
       settings3.beginGroup("thp_tweaks");
 
-      if (settings3.contains("blurless")) {
+  //    if (settings3.contains("blurless")) {
           if ( ui->blurless->checkState() == Qt::Checked ) {
               settings3.setValue("blurless","1");
           } else {
               settings3.setValue("blurless","0");
           }
-      }
+  //    }
 
-      if (settings3.contains("taskswitcher")) {
+  //    if (settings3.contains("taskswitcher")) {
           settings3.setValue("taskswitcher", ui->taskswitcher->currentIndex());
-      }
+  //    }
 
-      if (settings3.contains("zaxisrotation")) {
+ //     if (settings3.contains("zaxisrotation")) {
           if ( ui->zaxis->checkState() == Qt::Checked ) {
               settings3.setValue("zaxisrotation", "1");
           } else {
               settings3.setValue("zaxisrotation", "0");
           }
-      }
+  //    }
 
-      if (settings3.contains("forcerotation")) {
+  //    if (settings3.contains("forcerotation")) {
           if ( ui->forcerotation->checkState() == Qt::Checked ) {
               settings3.setValue("forcerotation", "1");
           } else {
               settings3.setValue("forcerotation", "0");
           }
-      }
+  //    }
 
-      if (settings3.contains("tactilepopups")) {
+ //     if (settings3.contains("tactilepopups")) {
           if ( ui->tactile->checkState() == Qt::Checked ) {
               settings3.setValue("tactilepopups", "1");
           } else {
               settings3.setValue("tactilepopups", "0");
           }
-      }
+  //    }
 
 
        settings3.endGroup();
 
        settings3.beginGroup("home");
 
-       if (settings3.contains("zoom_on_press")) {
+  //     if (settings3.contains("zoom_on_press")) {
           if ( ui->zoomonpress->checkState() == Qt::Checked ) {
               settings3.setValue("zoom_on_press", "1");
           } else {
               settings3.setValue("zoom_on_press", "0");
           }
-       }
+  //     }
 
 
     //      double parallaxdouble = ui->parallax->value();
-       if (settings3.contains("parallax")) {
-          double parallaxint = ui->parallax->value();
-          QString parallax = QString::number(parallaxint);
-          parallax.replace(',', '.');
+   //    if (settings3.contains("parallax")) {
           settings3.setValue("parallax", parallax);
-      }
+   //   }
 
-       if (settings3.contains("radius_more")) {
-           int radius_moreint = ui->blur->value();
-           QString radius_more = QString::number(radius_moreint);
-        //   parallax.replace(',', '.');
-          // QMaemo5InformationBox::information(this, parallax, QMaemo5InformationBox::DefaultTimeout);
+   //    if (settings3.contains("radius_more")) {
           settings3.setValue("radius_more", radius_more);
-      }
+   //   }
 
        settings3.endGroup();
 
@@ -442,8 +428,8 @@ void mainwindow::on_buttonBox_clicked(QAbstractButton* button)
 	{
             storevalues();
 	    QMessageBox msgBox;
-	    msgBox.setWindowTitle("CSSU Transitions Tuner");
-	    msgBox.setText("Transitions updated! <br /><br />Reboot is required to activate all changes.");
+            msgBox.setWindowTitle(tr("Transitions updated!"));
+            msgBox.setText(tr("Reboot is required to activate all changes."));
 	    msgBox.exec();
 	    break;
 	}
